@@ -17,35 +17,37 @@ import records #record data
 from functions_general import *
 from functions_record import *
 
-
+#load language file
+import i18n
+_ = i18n.language.gettext
 
 ###########################################################################
-## Function to open or close the log file
+## Function to open or close the record file
 ###########################################################################
 def CreateRecordFile(interval):
-    #if not on the N900, use another place for the log file
-    if(data.demo==True): data.logfolder=data.devlogfolder #folder on devel PC
-    else: data.logfolder=data.defaultlogfolder
+    #if not on the N900, use another place for the record file
+    if(data.demo==True): data.RecordFolder=data.developmentRecordFolder #folder on devel PC
+    else: data.RecordFolder=data.defaultRecordFolder
 
-    print "Logfolder:",  data.logfolder
-    if(not os.path.exists(data.logfolder)): #create log folder
+    print "RecordFolder:",  data.RecordFolder
+    if(not os.path.exists(data.RecordFolder)): #create record folder
         try:
-            os.mkdir(data.logfolder)
+            os.mkdir(data.RecordFolder)
         except:
-            print "Failed to create logfolder!"
+            print "Failed to create RecordFolder!"
 
     if(data.debug==1): PrintRecordData()
 
 
     #create file, write header
     d=strftime("%Y-%m-%d_%H-%M-%S", records.StartTime_tuple)
-    data.logfilename="SleepAnalyser_"+d+".csv"
-    data.logfile = open(data.logfolder+data.logfilename, 'w')
-    print "Created logfile "+data.logfilename
+    data.RecordFilename="SleepAnalyser_"+d+".csv"
+    data.RecordFile = open(data.RecordFolder+data.RecordFilename, 'w')
+    print "Created RecordFile "+data.RecordFilename
 
     h=CreateHeader()
-    data.logfile.write(h)
-    data.logfile.flush()
+    data.RecordFile.write(h)
+    data.RecordFile.flush()
 
 
 
@@ -104,61 +106,61 @@ def WriteRecord():
         str(records.arrData[3][records.Index-1]) + ", " +  \
         str(records.arrData[5][records.Index-1])
 
-    data.logfile.write(d+"\n")
+    data.RecordFile.write(d+"\n")
 #    if(data.debug==1): print "Write to file:",d
 
     if(records.Index % 30 == 0):
         if(data.debug==1): print "Flush data from IO buffer into file"
-        data.logfile.flush() #Every 30 indices (5 minutes in normal mode), write data from IO buffer into file
+        data.RecordFile.flush() #Every 30 indices (5 minutes in normal mode), write data from IO buffer into file
 
 
 
 
 ###########################################################################
-##  Close log file
+##  Close record file
 ###########################################################################
-def StopLogfile():
+def StopRecordFile():
     if(records.AlarmIsSet==True):
         records.LastIndex=max(records.Index,  Tuple2Index(records.AlarmTimeWindowEnd_tuple)+5) #the very last index to be shown (incl. AlarmTimeWindowEnd
     else: records.LastIndex=records.Index
-    data.logfile.close()
+    data.RecordFile.close()
 
 
 
 
 ###########################################################################
-##  Load list of log files into array
+##  Load list of record files into array
 ###########################################################################
 def LoadFileList():
-    print "Load list of all csv files in folder:",  data.logfolder
-    output = os.popen("cd "+str(data.logfolder)+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
-    data.arrLogFiles=output.split("\n")
-    data.arrLogFiles.pop()
-    if(data.debug==1): print data.arrLogFiles
-    if(data.logfilename>""):
-        if(data.debug==1): print data.logfilename
-        data.arrLogFileIndex=0
-        for i in range(len(data.arrLogFiles)):
-            if(data.logfilename==data.arrLogFiles[i]): data.arrLogFileIndex=i
+    print "Load list of all csv files in folder:",  data.RecordFolder
+    output = os.popen("cd "+str(data.RecordFolder)+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
+    data.arrRecordFiles=output.split("\n")
+    data.arrRecordFiles.pop()
+    if(data.debug==1): print data.arrRecordFiles
+    if(data.RecordFilename>""):
+        if(data.debug==1): print data.RecordFilename
+        data.arrRecordFilesIndex=0
+        for i in range(len(data.arrRecordFiles)):
+            if(data.RecordFilename==data.arrRecordFiles[i]): data.arrRecordFilesIndex=i
 
-    if(data.debug==1): print "LoadFileList,  Index:",  data.arrLogFileIndex
+    if(data.debug==1): print "LoadFileList,  Index:",  data.arrRecordFilesIndex
 
 
 
 
 ###########################################################################
-##  Load log file  to read and visualise it
+##  Load record file  to read and visualise it
 ###########################################################################
 def LoadRecord():
     InitRecord() #clear all old data
 
-    data.logfolder=string.replace(data.logfolder, "~",  data.homedir) #workaround
-    print "Open Log file:",  data.logfolder+data.logfilename,  "to load data..."
-    if(not os.path.exists(data.logfolder)): #create log folder (dirty workaround for if folder is not existing
-        os.mkdir(data.logfolder)
+    data.RecordFolder=string.replace(data.RecordFolder, "~",  data.homedir) #workaround
+    print "Open recordfile:",  data.RecordFolder+data.RecordFilename,  "to load data..."
+    if(not os.path.exists(data.RecordFolder)): #create record folder (dirty workaround for if folder is not existing
+        os.mkdir(data.RecordFolder)
         data.LastRecord=""
-    f=data.logfolder+data.logfilename
-    if(not os.path.exists(f) or data.logfilename==""): return 2 #selected file or folder does not exist
+    f=data.RecordFolder+data.RecordFilename
+    if(not os.path.exists(f) or data.RecordFilename==""): return 2 #selected file or folder does not exist
 
     file = open(f, 'r')
 
@@ -317,6 +319,7 @@ def LoadRecord():
     else: records.LastIndex=records.Index
 
     records.status=_("Data successful loaded")
+    print records.status
     records.statusID="OK"
 
     if(data.debug==1): PrintRecordData(False)
@@ -332,9 +335,9 @@ def LoadRecord():
 ##
 ###########################################################################
 def UpdateFileHeader():
-#    print "Reopen log file and update note:",  records.Note
-    file = open(data.logfolder+data.logfilename, 'w')
-    print "Update header in logfile",  data.logfilename
+#    print "Reopen record file and update note:",  records.Note
+    file = open(data.RecordFolder+data.RecordFilename, 'w')
+    print "Update header in RecordFile",  data.RecordFilename
 
     h=CreateHeader()
     file.write(h)
