@@ -140,7 +140,7 @@ def FilterData():
         arrSend[i]=records.arrData[4][i]
 
     #Exported function:
-    arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, 61-data.FilterScale, data.Ysize-7, 13)
+    arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, 61-data.FilterScale, data.Ysize-7, 13, data.limitMovement)
 
     for i in range(0,  records.Index-data.Derivation): #copy array and scale
         records.arrData[6][i]  = arrRet[i]
@@ -810,4 +810,4 @@ def PrintRecordData(ShowArray=True):
         for i in range(0, records.Index): #print data of  records
             print records.arrData[0][i],  records.arrData[1][i],  records.arrData[2][i],  records.arrData[3][i],  records.arrData[4][i],  records.arrData[5][i]
 
-    print "##########################################################"
\ No newline at end of file
+    print "##########################################################"
