@@ -16,7 +16,7 @@ extern list<__ss_int> *arFiltertest, *arTest;
 extern str *__name__;
 
 __ss_bool IsCompiled();
-list<__ss_int> *sleep_filter(list<__ss_int> *ar, __ss_int l, list<__ss_int> *filter, __ss_int shift, __ss_int scale, __ss_int max);
+list<__ss_int> *sleep_filter(list<__ss_int> *ar, __ss_int l, list<__ss_int> *filter, __ss_int shift, __ss_int scale, __ss_int max, __ss_int min, __ss_int limitMovement);
 
 PyMODINIT_FUNC initmylib(void);
 
