@@ -1,7 +1,7 @@
 #!/usr/bin/env python2.5
 ###########################################################################
 ## Name: 	       SleepAnalyser
-## Description:  Sleep Analyser records your movement during your sleep. It is able to visualise it on a graph to show
+## Description:   Sleep Analyser records your movement during your sleep. It is able to visualise it on a graph to show
 ##                      how much you move during your sleep. This can help to indicate how you sleep. It also has an alarm
 ##                      function. You can set the alarm and a time window (ex. 30 minutes). The Alarm will then go off
 ##                      sometimes during the time window (as soon as you move more), but latest at the set alarm.
@@ -12,30 +12,24 @@
 ## Licence:        GPL
 ###########################################################################
 
-#import sys
-#import random
-#import time
-#from time import strftime
-#import math
-#import array
-#import string
-
-
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
-
-#import ConfigParser
-#import os, os.path
+import os
 
 import dbus
 from dbus.mainloop.qt import DBusQtMainLoop
 
-
-
-
 import data #own data
 import records #record data
 
+#app path has to be set before  first use!
+data.app_path=os.path.dirname(__file__)
+if(data.app_path==""): data.app_path="./"
+else: data.app_path=data.app_path+"/"
+
+#load language file
+import i18n
+_ = i18n.language.gettext
 
 #own functions
 from functions_general import *
@@ -51,18 +45,6 @@ except:
     MyLib_Imported=False
 
 
-data.app_path=os.path.dirname(__file__)
-if(data.app_path==""): data.app_path="./"
-else: data.app_path=data.app_path+"/"
-
-
-#load language file
-import i18n
-_ = i18n.language.gettext
-#print _("Special character test: (*** INSERT SOME SPECIAL CHARACTERS IN YOUR LANGUAGE TO TEST THE TRANSLATION. IT WILL BE SHOWN IN THE TERMINAL ***)")
-
-
-
 #GUIs
 from Ui_StartWindow import *
 from Ui_RecordWindow import *
@@ -75,15 +57,6 @@ from Ui_AskForKeepWindow import *
 from Ui_AdditionalInfoWindow import *
 
 
-#ar=[1, 1]
-#print ar
-#mylib.test_shedskin(ar)
-#print ar
-#exit
-
-
-
-
 
 ###########################################################################
 ## Main function
@@ -109,31 +82,13 @@ def main():
 
     if(data.demo==True):
         print "Runs not on a N900 => Use randomizer for acceleration sensor data"
-        data.configfolder=data.devconfigfolder
-        data.logfolder=data.devlogfolder
-    else: data.logfolder=data.defaultlogfolder
-
-
-#
-#    data.app_path=os.path.dirname(__file__)
-#    if(data.app_path==""): data.app_path="./"
-#    else: data.app_path=data.app_path+"/"
-
-
-
+        data.configFolder=data.developmentconfigFolder
+        data.RecordFolder=data.developmentRecordFolder
+    else: data.RecordFolder=data.defaultRecordFolder
 
 
     config=LoadConfig()
 
-#    if(data.Ysize==120): #workaround for wrong defaults
-#        data.Ysize=121
-#        data.Yscale=1
-#        data.Trigger=30
-#        config.set('main', 'Ysize', str(data.Ysize))
-#        config.set('main', 'Yscale', str(data.Yscale))
-#        print "changed default parameters for Yscale and Ysize"
-
-
     #Load version file
     try:
         if(data.debug==1): print "Application path:",  data.app_path
@@ -175,7 +130,7 @@ def main():
 
     #Load Stylesheet for buttons
     try:
-        file = open(data.configfolder+"UIStyle2.css", 'r')
+        file = open(data.configFolder+"UIStyle2.css", 'r')
         data.UIStyle=""
         for line in file: data.UIStyle=data.UIStyle+line+"\n"
         file.close()
@@ -187,8 +142,8 @@ def main():
 #        for line in file: data.UIStyle=data.UIStyle+line+"\n"
 #        file.close()
 #        try:
-#            print "Create user defined style sheet in",  data.configfolder
-#            file= open(data.configfolder+"UIStyle.css", 'w')
+#            print "Create user defined style sheet in",  data.configFolder
+#            file= open(data.configFolder+"UIStyle.css", 'w')
 #            file.write(data.UIStyle)
 #            file.close()
 #        except:
@@ -222,7 +177,7 @@ def main():
     AdditionalInfoWindow.hide()
     AskForKeepWindow.hide()
 
-    #get user name for in log files
+    #get user name for in record files
     if(data.user==""):
         EditUserName()
 
@@ -283,6 +238,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
             QtGui.QMessageBox.warning(RecordWindow, txt, _("You reached the end of the recording capacity!\nThe recording stops now."), QtGui.QMessageBox.Ok)
 #            RecordWindow.StopMeasurement()
             StopMeasurement() #stop but keep alarm active!
+            SwitchModes(False) #change back to normal mode and general profile if requested
 
     ProcessAlarm()
 
@@ -295,9 +251,9 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 
 
 #    print data.AlarmIsActive,  data.StopAfterAlarm
-    if(data.AlarmIsActive==True):
+    if(data.AlarmIsActive==True): #alarm got activated
 #        print "Alarm is active"
-        if(data.StopAfterAlarm==True):
+        if(data.StopAfterAlarm==True): #stop recording
 #            print "Stop measurement, alarm is active"
             txt=_("Alarm got activated, stopped recording")
             print txt
@@ -307,12 +263,17 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
             #change directly to view screen
 #            DeleteAlarm() #delete Alarm if existing
 #            records.AlarmIsSet=False
-            data.LastRecord=data.logfilename #set to corrent file for viewwindow
+            data.LastRecord=data.RecordFilename #set to corrent file for viewwindow
             config.set('main', 'LastRecord', str(data.LastRecord))
             print "Show record in ViewWindow:",  data.LastRecord
             StartWindow.ShowViewWindow()
             RecordWindow.hide()
 
+        else: #continue recording
+            pass
+
+        SwitchModes(False) #change back to normal mode and general profile if requested
+
 
 
 
@@ -384,47 +345,10 @@ def InitMeasurement():
         print "Sampling interval:", data.interval, "ms"
         print "sample_smoothing:", data.Sample_smoothing, "x"
         print "value_smoothing:", data.Value_smoothing, "x"
-        print "=> log interval:", data.interval*data.Value_smoothing, "ms"
+        print "=> record interval:", data.interval*data.Value_smoothing, "ms"
         print "Derivation:", data.Derivation, "(substracts value", data.Derivation, "- value 0)"
 
-
-
-     #change to offline mode and silent profile if requested
-    if(data.demo==False): #We are on a N900
-        if(data.QuickMode==False):
-            if(data.OfflineMode==True): #change to offline mode
-                try:
-                    cmd="dbus-send --system --dest=com.nokia.mce --print-reply --type=method_call /com/nokia/mce/request com.nokia.mce.request.get_device_mode"
-                    ret=os.popen2(cmd) #get current mode
-                    p=ret[1].readline() #not used
-                    p=ret[1].readline()
-                    tmp=string.split(p,  "\"")
-                    data.PreviousMode=tmp[1]
-                    if(data.PreviousMode=="normal"): #was normal, change to offline
-                        cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
-                        os.popen(cmd)
-                except:
-                    pass
-
-            if(data.SilentProfile==True): #change to silent profile
-                try:
-                    cmd="dbus-send --type=method_call --print-reply --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.get_profile"
-                    ret=os.popen2(cmd) #get current profile
-                    p=ret[1].readline() #not used
-                    p=ret[1].readline()
-                    tmp=string.split(p,  "\"")
-                    data.PreviousProfile=tmp[1]
-                    if(data.PreviousProfile=="general"): #was general, change to silent
-                        cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"silent\" | echo \"\""
-                        os.popen(cmd)
-                        txt=_("Silent Profile activated")
-                        print txt
-                        cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+txt+"\""
-                        os.popen(cmd)
-                except:
-                    pass
-
-
+    SwitchModes(True) #change to offline mode and silent profile if requested
 
 
 ###########################################################################
@@ -446,33 +370,11 @@ def StopMeasurement():
     if(data.run==True): #in recording
         if(data.debug==1): print "Stop Timer"
         app.timer_GetData.stop()
-        StopLogfile()
-        UpdateFileHeader() #rewrite log file (only do when recording is stopped!)
+        StopRecordFile()
+        UpdateFileHeader() #rewriterecord file (only do when recording is stopped!)
 
     data.run=False
 
-    #change back to normal mode and general profile if requested
-    if(data.demo==False): #We are on a N900
-        if(data.QuickMode==False): #normal mode
-            if(data.OfflineMode==True and data.demo!=1): #change to offline mode
-                try:
-                    if(data.PreviousMode=="normal"): #was normal (before start measurement), so restore to normal
-                        cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"normal\""
-                        os.popen(cmd)
-                except:
-                    pass
-            if(data.SilentProfile==True and data.demo!=1): #change to offline mode
-                try:
-                    if(data.PreviousProfile=="general"): #was general (before start measurement), so restore to general
-                        cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"general\" | echo \"\""
-                        os.popen(cmd)  #set profile
-                        txt=_("General Profile activated")
-                        cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+txt+"\""
-                        os.popen(cmd)  #notification
-                except:
-                    pass
-
-
     RecordWindow.UpdateScreenStop()
 
 
@@ -498,7 +400,6 @@ def Zoom(direction):
 
 
 
-
 ###########################################################################
 ## Raise or lower the Trigger in the graph + sleep phases
 ###########################################################################
@@ -522,7 +423,7 @@ def About(ui):
     _("Feedback and donations are very welcome!")+"\n\n"+\
     _("Translations:")+\
     "\nEnglish, Deutsch: George Ruinelli\n"+\
-    "Francais: ??")
+    "Francais: Fred Kwame Ayanful")
 
 
 
@@ -557,13 +458,13 @@ class frmStartWindow(QMainWindow):
         self.ui.setupUi(self)
 
         QtCore.QObject.connect(self.ui.bCollecting, QtCore.SIGNAL("clicked()"), self.StartMeasurementNormal)
-        QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), self.ShowViewWindow)
+        QtCore.QObject.connect(self.ui.bView, QtCore.SIGNAL("clicked()"), self.ShowViewWindow)
         QtCore.QObject.connect(self.ui.bSetAlarm, QtCore.SIGNAL("clicked()"), self.SetAlarm)
 
         #Add styles to buttons
         self.ui.bCollecting.setStyleSheet(data.UIStyle)
         self.ui.bSetAlarm.setStyleSheet(data.UIStyle)
-        self.ui.bLog.setStyleSheet(data.UIStyle)
+        self.ui.bView.setStyleSheet(data.UIStyle)
 
 
         QtCore.QObject.connect(self.ui.actionTest_recording, QtCore.SIGNAL("triggered()"), self.StartMeasurementQuick)
@@ -577,13 +478,13 @@ class frmStartWindow(QMainWindow):
             self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"img/"+"SleepAnalyser.png"))
 #            self.ui.bQuick.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
             self.ui.bCollecting.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
-            self.ui.bLog.setIcon(QIcon(data.app_path+"img/"+"zoom.png"))
+            self.ui.bView.setIcon(QIcon(data.app_path+"img/"+"zoom.png"))
 #            self.ui.bConfig.setIcon(QIcon(data.app_path+"img/"+"configure.png"))
 
 
         #set texts
         self.setWindowTitle("SleepAnalyser")
-        self.ui.bLog.setText(_("View records"))
+        self.ui.bView.setText(_("View records"))
         self.ui.bCollecting.setText(_("Start recording only"))
         self.ui.bSetAlarm.setText(_("Set alarm and\nstart recording"))
         self.ui.menuMenu.setTitle(_("Menu"))
@@ -649,38 +550,38 @@ class frmStartWindow(QMainWindow):
         ViewWindow.show()
         app.processEvents() #force ui update
 
-        #reset to default log folder
-        if(data.demo==True): data.logfolder=data.devlogfolder #folder on devel PC
-        else: data.logfolder=data.defaultlogfolder
+        #reset to default record folder
+        if(data.demo==True): data.RecordFolder=data.developmentRecordFolder #folder on devel PC
+        else: data.RecordFolder=data.defaultRecordFolder
 
         LoadFileList()
-        data.arrLogFileIndex=len(data.arrLogFiles)-1 #no file selected, show latest
+        data.arrRecordFilesIndex=len(data.arrRecordFiles)-1 #no file selected, show latest
 
-        if os.path.exists(data.logfolder+data.LastRecord):
-            data.logfilename=data.LastRecord
+        if os.path.exists(data.RecordFolder+data.LastRecord):
+            data.RecordFilename=data.LastRecord
         else:
-            l=len(data.arrLogFiles)
+            l=len(data.arrRecordFiles)
             if(l>0):
-                data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
-            else: #no logfiles in logfolder, show "open file" dialog
+                data.RecordFilename=data.arrRecordFiles[l-1] #open last (youngest)record file
+            else: #no RecordFiles in RecordFolder, show "open file" dialog
                 tmp=ViewWindow.ShowFileDialog()
-                if(not os.path.exists(tmp)): #only continue if valid log file selected
+                if(not os.path.exists(tmp)): #only continue if valid record file selected
                     StartWindow.show()
                     ViewWindow.hide()
-                    return #only continue if valid log file selected
+                    return #only continue if valid record file selected
                 tmp2=tmp.split("/")
                 l=len(tmp2)
-                data.logfilename=tmp2[l-1]
-                data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
-                print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
+                data.RecordFilename=tmp2[l-1]
+                data.RecordFolder=string.replace(tmp,  data.RecordFilename,  "") #get folder of selected file
+                print "Set folder=",  data.RecordFolder,  ", file=",  data.RecordFilename
 
 
         ViewWindow.ShowRecord()
 
-#        if(data.logfilename!=""):
+#        if(data.RecordFilename!=""):
 #            ViewWindow.show()
 #        else:
-        if(data.logfilename==""):
+        if(data.RecordFilename==""):
             print "No valid file selected"
             ViewWindow.hide()
 
@@ -791,7 +692,7 @@ class frmRecordWindow(QMainWindow):
         self.setWindowTitle("SleepAnalyser ("+_("Recording")+")")
         self.ui.lblElapsedTime.setText(_("Elapsed time:")+" 0")
         self.ui.bStop.setText(_("Stop"))
-        self.ui.lblAlarmTime.setText(_("Alarm time: (not set)"))
+        self.ui.lblAlarmTime.setText(_("Alarm time: (no alarm set)"))
         self.ui.lblStatus2.setText(_("Status:"))
         self.ui.lblStatus.setText(_("Loading..."))
         self.ui.menuMenu.setTitle(_("Menu"))
@@ -817,7 +718,7 @@ class frmRecordWindow(QMainWindow):
 #            self.ui.lblAlarmTime.setText(str(data.AlarmHour)+":"+m+" or up to "+str(data.AlarmTimeWindow)+" minutes before that")
             self.ui.lblAlarmTime.setText(_("Alarm time:")+" "+strftime("%H:%M", records.AlarmTimeWindowStart_tuple)+" - "+strftime("%H:%M", records.AlarmTimeWindowEnd_tuple))
         else: #Do only recording, no alarm
-            self.ui.lblAlarmTime.setText(_("Alarm time: (No Alarm set)"))
+            self.ui.lblAlarmTime.setText(_("Alarm time: (no alarm set)"))
 
 #        self.ui.lblNote.setText("Note: ")
         self.UpdateScreen()
@@ -939,12 +840,13 @@ class frmRecordWindow(QMainWindow):
 #            pass #close
         else: #quick mode, delete file anyway and close
             StopMeasurement()
-            print "Delete logfile: "+data.logfilename
-            os.remove(data.logfolder+data.logfilename)
+            print "Delete RecordFile: "+data.RecordFilename
+            os.remove(data.RecordFolder+data.RecordFilename)
             data.QuickMode=False
             StartWindow.show()
             RecordWindow.hide()
             self.hide()
+            SwitchModes(False) #change back to normal mode and general profile if requested
 
 
 
@@ -953,7 +855,7 @@ class frmRecordWindow(QMainWindow):
         if(r[1]==True): #OK pressed
             records.Note=unicode(r[0])
 #            self.ui.lblNote.setText("Note: "+records.Note)
-            if(data.run==True): UpdateFileHeader() #rewrite log file (only do when recording is stopped!)
+            if(data.run==True): UpdateFileHeader() #rewrite record file (only do when recording is stopped!)
 
 
 
@@ -1045,7 +947,9 @@ class frmViewWindow(QMainWindow):
         self.ui.lblstate1.setText(_("Awake"))
         self.ui.lblstate2.setText(_("Light sleep"))
         self.ui.lblstate3.setText(_("Deep sleep"))
-
+        self.ui.actionShowRecordData.setText(_("Additional information"))
+        self.ui.actionAbout.setText(_("About"))
+        self.ui.actionExport.setText(_("Export as image"))
 
 
 
@@ -1082,7 +986,7 @@ class frmViewWindow(QMainWindow):
         if(data.Trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
 
-        if(len(data.arrLogFiles)<2): #disable last/next buttons if only one file in folder
+        if(len(data.arrRecordFiles)<2): #disable last/next buttons if only one file in folder
             self.ui.bNext.setEnabled(False)
             self.ui.bLast.setEnabled(False)
         else:
@@ -1124,13 +1028,13 @@ class frmViewWindow(QMainWindow):
             self.OpenRecord()
             return
 #        elif(r==3): #file is corrupted => draw empty graph
-#            QtGui.QMessageBox.warning(self, 'File corrupded!', "The data in the record file\n"+data.logfilename+"\nis invalid!\nNo data loaded.", QtGui.QMessageBox.Ok)
+#            QtGui.QMessageBox.warning(self, 'File corrupded!', "The data in the record file\n"+data.RecordFilename+"\nis invalid!\nNo data loaded.", QtGui.QMessageBox.Ok)
 #        elif(r==8): #file header is corrupted
-#            QtGui.QMessageBox.warning(self, 'File header corrupted!', "The header data in the record file\n"+data.logfilename+"\nis invalid!\nNo data loaded.", QtGui.QMessageBox.Ok)
+#            QtGui.QMessageBox.warning(self, 'File header corrupted!', "The header data in the record file\n"+data.RecordFilename+"\nis invalid!\nNo data loaded.", QtGui.QMessageBox.Ok)
 #        elif(r==4): #file is empty
-#            QtGui.QMessageBox.warning(self, 'File empty!', "The data in the record file\n"+data.logfilename+"\ncontains no data!", QtGui.QMessageBox.Ok)
+#            QtGui.QMessageBox.warning(self, 'File empty!', "The data in the record file\n"+data.RecordFilename+"\ncontains no data!", QtGui.QMessageBox.Ok)
 #        elif(r==9): #Record too old
-#            QtGui.QMessageBox.warning(self, 'File version too old!', "Can not load record \n"+data.logfilename+"\nas it got created from SleepAnalyser version <1.6 and is not compatible with the current SleepAnalyser version.", QtGui.QMessageBox.Ok)
+#            QtGui.QMessageBox.warning(self, 'File version too old!', "Can not load record \n"+data.RecordFilename+"\nas it got created from SleepAnalyser version <1.6 and is not compatible with the current SleepAnalyser version.", QtGui.QMessageBox.Ok)
 #        LoadFileList()
 
         if(data.demo==False): #We are on a N900
@@ -1174,16 +1078,16 @@ class frmViewWindow(QMainWindow):
     ##
     ###########################################################################
     def NextRecord(self): ##(Class ViewWindow)
-        data.arrLogFileIndex=(data.arrLogFileIndex+1)  % len(data.arrLogFiles)
-        data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
+        data.arrRecordFilesIndex=(data.arrRecordFilesIndex+1)  % len(data.arrRecordFiles)
+        data.RecordFilename=data.arrRecordFiles[data.arrRecordFilesIndex]
         self.ShowRecord()
 
     ###########################################################################
     ##
     ###########################################################################
     def LastRecord(self): ##(Class ViewWindow)
-        data.arrLogFileIndex=(data.arrLogFileIndex-1)  % len(data.arrLogFiles)
-        data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
+        data.arrRecordFilesIndex=(data.arrRecordFilesIndex-1)  % len(data.arrRecordFiles)
+        data.RecordFilename=data.arrRecordFiles[data.arrRecordFilesIndex]
         self.ShowRecord()
 
 
@@ -1195,16 +1099,11 @@ class frmViewWindow(QMainWindow):
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
         Zoom(+1)
+
         self.ui.bZoomOut.setEnabled(True)
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
 
-#        print "records.LastIndex:",  records.LastIndex, data.arrXscale[data.Xscale]*775
-#        data.GraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
-#        print "GraphStart:",  data.GraphStart
-
-#        data.ChangesInGraph=True #Make sure it only gets refreshed once
-
         GenerateGraphBitmap(self, True)
 
         self.ui.lblStatus.hide()
@@ -1228,10 +1127,6 @@ class frmViewWindow(QMainWindow):
         if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
         else: self.ui.bZoomOut.setEnabled(True)
 
-#        data.GraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
-
-#        data.ChangesInGraph=True #Make sure it only gets refreshed once
-
         GenerateGraphBitmap(self, True)
 
         self.ui.lblStatus.hide()
@@ -1250,7 +1145,6 @@ class frmViewWindow(QMainWindow):
 
         GenerateStatisticData()
         GenerateStatisticsBitmap(self)
-#        self.update() #update statistic bars
         self.ui.lblStatus.hide()
 
 
@@ -1267,7 +1161,6 @@ class frmViewWindow(QMainWindow):
 
         GenerateStatisticData()
         GenerateStatisticsBitmap(self)
-#        self.update() #update statistic bars
         self.ui.lblStatus.hide()
 
 
@@ -1280,27 +1173,27 @@ class frmViewWindow(QMainWindow):
     def DeleteRecord(self): ##(Class ViewWindow)
         self.ui.lblStatus.setText(_("Delete record..."))
         self.ui.lblStatus.show()
-        reply = QtGui.QMessageBox.question(self, _("Delete record?"), _("Are you sure you want to delete this record:")+"\n"+data.logfilename, QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+        reply = QtGui.QMessageBox.question(self, _("Delete record?"), _("Are you sure you want to delete this record:")+"\n"+data.RecordFilename, QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
         if reply == QtGui.QMessageBox.Yes:
-            print "Delete logfile: "+data.logfilename
-            os.remove(data.logfolder+data.logfilename)
+            print "Delete RecordFile: "+data.RecordFilename
+            os.remove(data.RecordFolder+data.RecordFilename)
 
-            index=data.arrLogFileIndex
+            index=data.arrRecordFilesIndex
             LoadFileList()
-            if(len(data.arrLogFiles)>0):
-#                data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
-                data.arrLogFileIndex=index-1
-                data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
-            else: #no logfiles in logfolder, show "open file" dialog
+            if(len(data.arrRecordFiles)>0):
+#                data.RecordFilename=data.arrRecordFiles[l-1] #open last (youngest) record file
+                data.arrRecordFilesIndex=index-1
+                data.RecordFilename=data.arrRecordFiles[data.arrRecordFilesIndex]
+            else: #no RecordFiles in RecordFolder, show "open file" dialog
                 tmp=self.ShowFileDialog()
-                if(tmp==""): #only continue if valid log file selected
+                if(tmp==""): #only continue if valid record file selected
                     self.closeEvent("") #no file selected, close
                     return
                 tmp2=tmp.split("/")
                 l=len(tmp2)
-                data.logfilename=tmp2[l-1]
-                data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
-                print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
+                data.RecordFilename=tmp2[l-1]
+                data.RecordFolder=string.replace(tmp,  data.RecordFilename,  "") #get folder of selected file
+                print "Set folder=",  data.RecordFolder,  ", file=",  data.RecordFilename
             self.ShowRecord()
             self.UpdateScreen()
         self.ui.lblStatus.hide()
@@ -1323,14 +1216,14 @@ class frmViewWindow(QMainWindow):
 
 
         tmp=self.ShowFileDialog()
-        if(not os.path.exists(tmp)): #only continue if valid log file selected
+        if(not os.path.exists(tmp)): #only continue if valid record file selected
             self.ui.lblStatus.hide()
             return
         tmp2=tmp.split("/")
         l=len(tmp2)
-        data.logfilename=tmp2[l-1]
-        data.logfolder=string.replace(tmp,  data.logfilename,  "") #get folder of selected file
-        print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
+        data.RecordFilename=tmp2[l-1]
+        data.RecordFolder=string.replace(tmp,  data.RecordFilename,  "") #get folder of selected file
+        print "Set folder=",  data.RecordFolder,  ", file=",  data.RecordFilename
         LoadFileList()
         self.ShowRecord()
         self.ui.lblStatus.hide()
@@ -1341,9 +1234,9 @@ class frmViewWindow(QMainWindow):
     ##
     ###########################################################################
     def ShowFileDialog(self): ##(Class ViewWindow)
-        data.logfolder=string.replace(data.logfolder, "~",  data.homedir) #workaround
-        if(data.debug==1): print "Open file dialog in:",  data.logfolder
-        tmp= QFileDialog.getOpenFileName(None,_("Open SleepAnalyser record"), data.logfolder, _("Record Files")+" (*.csv)")
+        data.RecordFolder=string.replace(data.RecordFolder, "~",  data.homedir) #workaround
+        if(data.debug==1): print "Open file dialog in:",  data.RecordFolder
+        tmp= QFileDialog.getOpenFileName(None,_("Open SleepAnalyser record"), data.RecordFolder, _("Record Files")+" (*.csv)")
         print "Selected file:",  tmp
         return tmp
 
@@ -1375,7 +1268,7 @@ class frmViewWindow(QMainWindow):
             records.Note=tmp
 #            self.ui.lblNote.setText("Note: "+records.Note)
             self.ui.lblNote.setText(records.Note)
-            UpdateFileHeader() #rewrite log file (only do when recording is stopped!)
+            UpdateFileHeader() #rewrite record file (only do when recording is stopped!)
 
 
 
@@ -1401,8 +1294,8 @@ class frmViewWindow(QMainWindow):
 
 
     def Export(self): ##(Class ViewWindow)
-        filename=string.replace(data.logfilename, ".csv",  "")
-        tmp=QFileDialog.getSaveFileName(None,_("Export graph as"), data.defaultlogfolder+filename, _("PNG-Image")+" (*.png)") #;;JPEG-Image (*.jpg)
+        filename=string.replace(data.RecordFilename, ".csv",  "")
+        tmp=QFileDialog.getSaveFileName(None,_("Export graph as"), data.defaultRecordFolder+filename, _("PNG-Image")+" (*.png)") #;;JPEG-Image (*.jpg)
         if(tmp!=""):
             print "Export graph as :",  tmp
             r=data.GraphBitMap.save(tmp,  "png",  -1)
@@ -1494,7 +1387,7 @@ class frmConfigWindow(QMainWindow):
         self.ui.bEditUserName.setText(_("Change"))
         self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_General), _("General"))
         self.ui.lblDelayStart.setText(_("Start delay:"))
-        self.ui.lblYscale_Movement.setText(_("Y scaling movement bars (yellow):"))
+        self.ui.lblYscale_Movement.setText(_("Y scaling movement (yellow):"))
         self.ui.lblYscale_Sleep.setText(_("Y scaling sleep graph (blue):"))
         self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_Advanced), _("Advanced"))
         self.ui.lblMore.setText(_("More settings can be changed at your own risk in the file\n~/.SleepAnalyer/SleepAnalyser.conf."))
@@ -1520,7 +1413,7 @@ class frmConfigWindow(QMainWindow):
         self.ui.SlrYscale_Movement.setValue(int(data.Yscale))
 
 
-        self.ui.lblYscale_Sleep.setText(_("Y scaling sleep pattern (blue):")+" "+str(data.FilterScale))
+        self.ui.lblYscale_Sleep.setText(_("Y scaling sleep graph (blue):")+" "+str(data.FilterScale))
         self.ui.SlrYscale_Sleep.setValue(int(data.FilterScale))
 
 
@@ -1643,8 +1536,8 @@ class frmDateWindow(QMainWindow):
         date = self.ui.cal.selectedDate()
         date=str(date.toPyDate())
 
-#        print "Load list of all csv files in folder:",  data.logfolder + " with date " + date
-        output = os.popen("cd "+str(data.logfolder)+"; ls -C1 *"+date+"*.csv").read() # run ls and make the output look like a file I can read
+#        print "Load list of all csv files in folder:",  data.RecordFolder + " with date " + date
+        output = os.popen("cd "+str(data.RecordFolder)+"; ls -C1 *"+date+"*.csv").read() # run ls and make the output look like a file I can read
         arr=output.split("\n")
 
         amount=len(arr)-1
@@ -1655,12 +1548,12 @@ class frmDateWindow(QMainWindow):
         self.ui.lblResult.setText(txt)
         if(amount>0):
             self.ui.bOpen.setEnabled(True)
-            data.LogFileSelectedDate=arr[0] #select first file of that date for opening
+            data.RecordFileSelectedDate=arr[0] #select first file of that date for opening
 
-            for i in range(0,  len(data.arrLogFiles)-1):
-                if(data.arrLogFiles[i]==data.LogFileSelectedDate):
+            for i in range(0,  len(data.arrRecordFiles)-1):
+                if(data.arrRecordFiles[i]==data.RecordFileSelectedDate):
 #                    print "found:",  i
-                    data.arrLogFileIndex=i
+                    data.arrRecordFilesIndex=i
                     break
 
         else: self.ui.bOpen.setEnabled(False)
@@ -1670,8 +1563,8 @@ class frmDateWindow(QMainWindow):
     ##
     ###########################################################################
     def OpenRecord(self): ##(Class ConfigWindow)
-        data.logfilename=data.LogFileSelectedDate
-        print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
+        data.RecordFilename=data.RecordFileSelectedDate
+        print "Set folder=",  data.RecordFolder,  ", file=",  data.RecordFilename
         DateWindow.hide()
         ViewWindow.ShowRecord()
 
@@ -1700,7 +1593,7 @@ class frmAdditionalInfoWindow(QMainWindow):
     ##
     ###########################################################################
     def UpdateScreen(self): ##(Class AdditionalInfoWindow)
-        shortfolder=string.replace(data.logfolder, data.homedir, "~/")
+        shortfolder=string.replace(data.RecordFolder, data.homedir, "~/")
         shortfolder=string.replace(shortfolder, "//", "/") #workaround
 
         d0=strftime("%a. %d.%m.%Y  %H:%M:%S", records.StartTime_tuple)
@@ -1738,7 +1631,7 @@ class frmAdditionalInfoWindow(QMainWindow):
         else:
             alarm="<b>"+_("Alarm:")+"</b> "+_("No alarm was set")+"<br>"
 
-        txt= "<b>"+_("File:")+"</b> "+str(shortfolder)+str(data.logfilename+"<br>") + \
+        txt= "<b>"+_("File:")+"</b> "+str(shortfolder)+str(data.RecordFilename+"<br>") + \
         "<b>"+_("Date/Time:")+"</b> "+d0+" - "+d1+"<br>" + \
         "<b>"+_("Duration:")+"</b> "+ diff+"<br>" + \
         "<b>"+_("Record entries:")+"</b> "+str(records.Index)+" (1/"+str(int(records.Sampling_interval*records.Value_smoothing/1000))+" "+_("seconds")+")<br>" +\
@@ -1957,12 +1850,14 @@ class frmAskForKeepWindow(QMainWindow):
         StopMeasurement()
         DeleteAlarm() #delete Alarm if existing
         records.AlarmIsSet=False
-        data.LastRecord=data.logfilename #set to corrent file for viewwindow
+        data.LastRecord=data.RecordFilename #set to corrent file for viewwindow
         config.set('main', 'LastRecord', str(data.LastRecord))
         print "Show record in ViewWindow:",  data.LastRecord
         RecordWindow.hide()
         self.hide()
         StartWindow.ShowViewWindow()
+        app.processEvents() #force ui update
+        SwitchModes(False) #change back to normal mode and general profile if requested
 
 
 
@@ -1975,11 +1870,13 @@ class frmAskForKeepWindow(QMainWindow):
         StopMeasurement()
         DeleteAlarm() #delete Alarm if existing
         records.AlarmIsSet=False
-        print "Delete logfile: "+data.logfilename
-        os.remove(data.logfolder+data.logfilename)
+        print "Delete RecordFile: "+data.RecordFilename
+        os.remove(data.RecordFolder+data.RecordFilename)
         RecordWindow.hide()
-        StartWindow.show()
         self.hide()
+        StartWindow.show()
+        app.processEvents() #force ui update
+        SwitchModes(False) #change back to normal mode and general profile if requested
 
 
 
@@ -2216,4 +2113,3 @@ def GenerateStatisticsBitmap(self):
 
 ###########################################################################
 main() # Now we can start it.
-
